"rbern" <-

function(n, prob)



{



	rbinom(n,size=1,prob=prob)

	

}

